==> hermes-consumers-2.2.11-sources.jar: pl/allegro/tech/hermes/consumers/supervisor/workload/sbe/stubs/ProfilesEncoder.java <==
/* Generated SBE (Simple Binary Encoding) message codec */
package pl.allegro.tech.hermes.consumers.supervisor.workload.sbe.stubs;

import org.agrona.MutableDirectBuffer;
import org.agrona.DirectBuffer;

/**
 * Subscription profiles
 */
@SuppressWarnings("all")
public class ProfilesEncoder
{
    public static final int BLOCK_LENGTH = 8;
    public static final int TEMPLATE_ID = 3;
    public static final int SCHEMA_ID = 2;
    public static final int SCHEMA_VERSION = 0;
    public static final java.nio.ByteOrder BYTE_ORDER = java.nio.ByteOrder.LITTLE_ENDIAN;

    private final ProfilesEncoder parentMessage = this;
    private MutableDirectBuffer buffer;
    protected int offset;
    protected int limit;

    public int sbeBlockLength()
    {
        return BLOCK_LENGTH;
    }

    public int sbeTemplateId()
    {
        return TEMPLATE_ID;
    }

    public int sbeSchemaId()
    {
        return SCHEMA_ID;
    }

    public int sbeSchemaVersion()
    {
        return SCHEMA_VERSION;
    }

    public String sbeSemanticType()
    {
        return "";
    }

    public MutableDirectBuffer buffer()
    {
        return buffer;
    }

    public int offset()
    {
        return offset;
    }

    public ProfilesEncoder wrap(final MutableDirectBuffer buffer, final int offset)
    {
        if (buffer != this.buffer)
        {
            this.buffer = buffer;
        }
        this.offset = offset;
        limit(offset + BLOCK_LENGTH);

        return this;
    }

    public ProfilesEncoder wrapAndApplyHeader(
        final MutableDirectBuffer buffer, final int offset, final MessageHeaderEncoder headerEncoder)
    {
        headerEncoder
            .wrap(buffer, offset)
            .blockLength(BLOCK_LENGTH)
            .templateId(TEMPLATE_ID)
            .schemaId(SCHEMA_ID)
            .version(SCHEMA_VERSION);

        return wrap(buffer, offset + MessageHeaderEncoder.ENCODED_LENGTH);
    }

    public int encodedLength()
    {
        return limit - offset;
    }

    public int limit()
    {
        return limit;
    }

    public void limit(final int limit)
    {
        this.limit = limit;
    }

    public static int updateTimestampId()
    {
        return 1;
    }

    public static int updateTimestampSinceVersion()
    {
        return 0;
    }

    public static int updateTimestampEncodingOffset()
    {
        return 0;
    }

    public static int updateTimestampEncodingLength()
    {
        return 8;
    }

    public static String updateTimestampMetaAttribute(final MetaAttribute metaAttribute)
    {
        switch (metaAttribute)
        {
            case EPOCH: return "";
            case TIME_UNIT: return "";
            case SEMANTIC_TYPE: return "";
            case PRESENCE: return "required";
        }

        return "";
    }

    public static long updateTimestampNullValue()
    {
        return -9223372036854775808L;
    }

    public static long updateTimestampMinValue()
    {
        return -9223372036854775807L;
    }

    public static long updateTimestampMaxValue()
    {
        return 9223372036854775807L;
    }

    public ProfilesEncoder updateTimestamp(final long value)
    {
        buffer.putLong(offset + 0, value, java.nio.ByteOrder.LITTLE_ENDIAN);
        return this;
    }


    private final SubscriptionsEncoder subscriptions = new SubscriptionsEncoder(this);

    public static long subscriptionsId()
    {
        return 2;
    }

    public SubscriptionsEncoder subscriptionsCount(final int count)
    {
        subscriptions.wrap(buffer, count);
        return subscriptions;
    }

    public static class SubscriptionsEncoder
    {
        public static final int HEADER_SIZE = 4;
        private final ProfilesEncoder parentMessage;
        private MutableDirectBuffer buffer;
        private int count;
        private int index;
        private int offset;

        SubscriptionsEncoder(final ProfilesEncoder parentMessage)
        {
            this.parentMessage = parentMessage;
        }

        public void wrap(final MutableDirectBuffer buffer, final int count)
        {
            if (count < 0 || count > 65534)
            {
                throw new IllegalArgumentException("count outside allowed range: count=" + count);
            }

            if (buffer != this.buffer)
            {
                this.buffer = buffer;
            }

            index = -1;
            this.count = count;
            final int limit = parentMessage.limit();
            parentMessage.limit(limit + HEADER_SIZE);
            buffer.putShort(limit + 0, (short)(int)24, java.nio.ByteOrder.LITTLE_ENDIAN);
            buffer.putShort(limit + 2, (short)(int)count, java.nio.ByteOrder.LITTLE_ENDIAN);
        }

        public static int sbeHeaderSize()
        {
            return HEADER_SIZE;
        }

        public static int sbeBlockLength()
        {
            return 24;
        }

        public SubscriptionsEncoder next()
        {
            if (index + 1 >= count)
            {
                throw new java.util.NoSuchElementException();
            }

            offset = parentMessage.limit();
            parentMessage.limit(offset + sbeBlockLength());
            ++index;

            return this;
        }

        public static int idId()
        {
            return 3;
        }

        public static int idSinceVersion()
        {
            return 0;
        }

        public static int idEncodingOffset()
        {
            return 0;
        }

        public static int idEncodingLength()
        {
            return 8;
        }

        public static String idMetaAttribute(final MetaAttribute metaAttribute)
        {
            switch (metaAttribute)
            {
                case EPOCH: return "";
                case TIME_UNIT: return "";
                case SEMANTIC_TYPE: return "";
                case PRESENCE: return "required";
            }

            return "";
        }

        public static long idNullValue()
        {
            return -9223372036854775808L;
        }

        public static long idMinValue()
        {
            return -9223372036854775807L;
        }

        public static long idMaxValue()
        {
            return 9223372036854775807L;
        }

        public SubscriptionsEncoder id(final long value)
        {
            buffer.putLong(offset + 0, value, java.nio.ByteOrder.LITTLE_ENDIAN);
            return this;
        }


        public static int operationsPerSecondId()
        {
            return 4;
        }

        public static int operationsPerSecondSinceVersion()
        {
            return 0;
        }

        public static int operationsPerSecondEncodingOffset()
        {
            return 8;
        }

        public static int operationsPerSecondEncodingLength()
        {
            return 8;
        }

        public static String operationsPerSecondMetaAttribute(final MetaAttribute metaAttribute)
        {
            switch (metaAttribute)
            {
                case EPOCH: return "";
                case TIME_UNIT: return "";
                case SEMANTIC_TYPE: return "";
                case PRESENCE: return "required";
            }

            return "";
        }

        public static double operationsPerSecondNullValue()
        {
            return Double.NaN;
        }

        public static double operationsPerSecondMinValue()
        {
            return 4.9E-324d;
        }

        public static double operationsPerSecondMaxValue()
        {
            return 1.7976931348623157E308d;
        }

        public SubscriptionsEncoder operationsPerSecond(final double value)
        {
            buffer.putDouble(offset + 8, value, java.nio.ByteOrder.LITTLE_ENDIAN);
            return this;
        }


        public static int lastRebalanceTimestampId()
        {
            return 5;
        }

        public static int lastRebalanceTimestampSinceVersion()
        {
            return 0;
        }

        public static int lastRebalanceTimestampEncodingOffset()
        {
            return 16;
        }

        public static int lastRebalanceTimestampEncodingLength()
        {
            return 8;
        }

        public static String lastRebalanceTimestampMetaAttribute(final MetaAttribute metaAttribute)
        {
            switch (metaAttribute)
            {
                case EPOCH: return "";
                case TIME_UNIT: return "";
                case SEMANTIC_TYPE: return "";
                case PRESENCE: return "required";
            }

            return "";
        }

        public static long lastRebalanceTimestampNullValue()
        {
            return -9223372036854775808L;
        }

        public static long lastRebalanceTimestampMinValue()
        {
            return -9223372036854775807L;
        }

        public static long lastRebalanceTimestampMaxValue()
        {
            return 9223372036854775807L;
        }

        public SubscriptionsEncoder lastRebalanceTimestamp(final long value)
        {
            buffer.putLong(offset + 16, value, java.nio.ByteOrder.LITTLE_ENDIAN);
            return this;
        }

    }


    public String toString()
    {
        return appendTo(new StringBuilder(100)).toString();
    }

    public StringBuilder appendTo(final StringBuilder builder)
    {
        ProfilesDecoder writer = new ProfilesDecoder();
        writer.wrap(buffer, offset, BLOCK_LENGTH, SCHEMA_VERSION);

        return writer.appendTo(builder);
    }
}

==> hermes-consumers-2.6.15-sources.jar: pl/allegro/tech/hermes/consumers/supervisor/workload/sbe/stubs/ProfilesEncoder.java <==
/* Generated SBE (Simple Binary Encoding) message codec. */
package pl.allegro.tech.hermes.consumers.supervisor.workload.sbe.stubs;

import org.agrona.MutableDirectBuffer;


/**
 * Subscription profiles
 */
@SuppressWarnings("all")
public final class ProfilesEncoder
{
    public static final int BLOCK_LENGTH = 8;
    public static final int TEMPLATE_ID = 3;
    public static final int SCHEMA_ID = 2;
    public static final int SCHEMA_VERSION = 0;
    public static final String SEMANTIC_VERSION = "5.2";
    public static final java.nio.ByteOrder BYTE_ORDER = java.nio.ByteOrder.LITTLE_ENDIAN;

    private final ProfilesEncoder parentMessage = this;
    private MutableDirectBuffer buffer;
    private int offset;
    private int limit;

    public int sbeBlockLength()
    {
        return BLOCK_LENGTH;
    }

    public int sbeTemplateId()
    {
        return TEMPLATE_ID;
    }

    public int sbeSchemaId()
    {
        return SCHEMA_ID;
    }

    public int sbeSchemaVersion()
    {
        return SCHEMA_VERSION;
    }

    public String sbeSemanticType()
    {
        return "";
    }

    public MutableDirectBuffer buffer()
    {
        return buffer;
    }

    public int offset()
    {
        return offset;
    }

    public ProfilesEncoder wrap(final MutableDirectBuffer buffer, final int offset)
    {
        if (buffer != this.buffer)
        {
            this.buffer = buffer;
        }
        this.offset = offset;
        limit(offset + BLOCK_LENGTH);

        return this;
    }

    public ProfilesEncoder wrapAndApplyHeader(
        final MutableDirectBuffer buffer, final int offset, final MessageHeaderEncoder headerEncoder)
    {
        headerEncoder
            .wrap(buffer, offset)
            .blockLength(BLOCK_LENGTH)
            .templateId(TEMPLATE_ID)
            .schemaId(SCHEMA_ID)
            .version(SCHEMA_VERSION);

        return wrap(buffer, offset + MessageHeaderEncoder.ENCODED_LENGTH);
    }

    public int encodedLength()
    {
        return limit - offset;
    }

    public int limit()
    {
        return limit;
    }

    public void limit(final int limit)
    {
        this.limit = limit;
    }

    public static int updateTimestampId()
    {
        return 1;
    }

    public static int updateTimestampSinceVersion()
    {
        return 0;
    }

    public static int updateTimestampEncodingOffset()
    {
        return 0;
    }

    public static int updateTimestampEncodingLength()
    {
        return 8;
    }

    public static String updateTimestampMetaAttribute(final MetaAttribute metaAttribute)
    {
        if (MetaAttribute.PRESENCE == metaAttribute)
        {
            return "required";
        }

        return "";
    }

    public static long updateTimestampNullValue()
    {
        return -9223372036854775808L;
    }

    public static long updateTimestampMinValue()
    {
        return -9223372036854775807L;
    }

    public static long updateTimestampMaxValue()
    {
        return 9223372036854775807L;
    }

    public ProfilesEncoder updateTimestamp(final long value)
    {
        buffer.putLong(offset + 0, value, BYTE_ORDER);
        return this;
    }


    private final SubscriptionsEncoder subscriptions = new SubscriptionsEncoder(this);

    public static long subscriptionsId()
    {
        return 2;
    }

    public SubscriptionsEncoder subscriptionsCount(final int count)
    {
        subscriptions.wrap(buffer, count);
        return subscriptions;
    }

    public static final class SubscriptionsEncoder
    {
        public static final int HEADER_SIZE = 4;
        private final ProfilesEncoder parentMessage;
        private MutableDirectBuffer buffer;
        private int count;
        private int index;
        private int offset;
        private int initialLimit;

        SubscriptionsEncoder(final ProfilesEncoder parentMessage)
        {
            this.parentMessage = parentMessage;
        }

        public void wrap(final MutableDirectBuffer buffer, final int count)
        {
            if (count < 0 || count > 65534)
            {
                throw new IllegalArgumentException("count outside allowed range: count=" + count);
            }

            if (buffer != this.buffer)
            {
                this.buffer = buffer;
            }

            index = 0;
            this.count = count;
            final int limit = parentMessage.limit();
            initialLimit = limit;
            parentMessage.limit(limit + HEADER_SIZE);
            buffer.putShort(limit + 0, (short)24, BYTE_ORDER);
            buffer.putShort(limit + 2, (short)count, BYTE_ORDER);
        }

        public SubscriptionsEncoder next()
        {
            if (index >= count)
            {
                throw new java.util.NoSuchElementException();
            }

            offset = parentMessage.limit();
            parentMessage.limit(offset + sbeBlockLength());
            ++index;

            return this;
        }

        public int resetCountToIndex()
        {
            count = index;
            buffer.putShort(initialLimit + 2, (short)count, BYTE_ORDER);

            return count;
        }

        public static int countMinValue()
        {
            return 0;
        }

        public static int countMaxValue()
        {
            return 65534;
        }

        public static int sbeHeaderSize()
        {
            return HEADER_SIZE;
        }

        public static int sbeBlockLength()
        {
            return 24;
        }

        public static int idId()
        {
            return 3;
        }

        public static int idSinceVersion()
        {
            return 0;
        }

        public static int idEncodingOffset()
        {
            return 0;
        }

        public static int idEncodingLength()
        {
            return 8;
        }

        public static String idMetaAttribute(final MetaAttribute metaAttribute)
        {
            if (MetaAttribute.PRESENCE == metaAttribute)
            {
                return "required";
            }

            return "";
        }

        public static long idNullValue()
        {
            return -9223372036854775808L;
        }

        public static long idMinValue()
        {
            return -9223372036854775807L;
        }

        public static long idMaxValue()
        {
            return 9223372036854775807L;
        }

        public SubscriptionsEncoder id(final long value)
        {
            buffer.putLong(offset + 0, value, BYTE_ORDER);
            return this;
        }


        public static int operationsPerSecondId()
        {
            return 4;
        }

        public static int operationsPerSecondSinceVersion()
        {
            return 0;
        }

        public static int operationsPerSecondEncodingOffset()
        {
            return 8;
        }

        public static int operationsPerSecondEncodingLength()
        {
            return 8;
        }

        public static String operationsPerSecondMetaAttribute(final MetaAttribute metaAttribute)
        {
            if (MetaAttribute.PRESENCE == metaAttribute)
            {
                return "required";
            }

            return "";
        }

        public static double operationsPerSecondNullValue()
        {
            return Double.NaN;
        }

        public static double operationsPerSecondMinValue()
        {
            return 4.9E-324d;
        }

        public static double operationsPerSecondMaxValue()
        {
            return 1.7976931348623157E308d;
        }

        public SubscriptionsEncoder operationsPerSecond(final double value)
        {
            buffer.putDouble(offset + 8, value, BYTE_ORDER);
            return this;
        }


        public static int lastRebalanceTimestampId()
        {
            return 5;
        }

        public static int lastRebalanceTimestampSinceVersion()
        {
            return 0;
        }

        public static int lastRebalanceTimestampEncodingOffset()
        {
            return 16;
        }

        public static int lastRebalanceTimestampEncodingLength()
        {
            return 8;
        }

        public static String lastRebalanceTimestampMetaAttribute(final MetaAttribute metaAttribute)
        {
            if (MetaAttribute.PRESENCE == metaAttribute)
            {
                return "required";
            }

            return "";
        }

        public static long lastRebalanceTimestampNullValue()
        {
            return -9223372036854775808L;
        }

        public static long lastRebalanceTimestampMinValue()
        {
            return -9223372036854775807L;
        }

        public static long lastRebalanceTimestampMaxValue()
        {
            return 9223372036854775807L;
        }

        public SubscriptionsEncoder lastRebalanceTimestamp(final long value)
        {
            buffer.putLong(offset + 16, value, BYTE_ORDER);
            return this;
        }

    }

    public String toString()
    {
        if (null == buffer)
        {
            return "";
        }

        return appendTo(new StringBuilder()).toString();
    }

    public StringBuilder appendTo(final StringBuilder builder)
    {
        if (null == buffer)
        {
            return builder;
        }

        final ProfilesDecoder decoder = new ProfilesDecoder();
        decoder.wrap(buffer, offset, BLOCK_LENGTH, SCHEMA_VERSION);

        return decoder.appendTo(builder);
    }
}
